Welcome to pyshotgrid's documentation!
======================================

.. include:: ../README.md
   :parser: myst_parser.sphinx_

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   installation
   user_guide
   contributing
   how_it_works
   how_to_add_custom_entities
   pyshotgrid_vs_shotgun_api3
   api_reference
   changelog

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
